package model

import (
	"go.mongodb.org/mongo-driver/bson/primitive"
)

type Post struct {
	ID       primitive.ObjectID `bson:"_id,omitempty" json:"id,omitempty"`
	UID      string             `bson:"uid" json:"uid"`             // 搜尋條件
	Content  string             `bson:"content" json:"content"`     // 內容
	Status   int8               `bson:"status" json:"status"`       // 1. 等待審核中 , 2 審核通過，預設為 1 ->過濾條件
	IsAd     bool               `bson:"is_ad" json:"is_ad"`         // 此則貼文是否為廣告貼文 -> 過濾條件
	Tags     []string           `bson:"tags" json:"tags"`           // 本則貼文的標籤，不提供搜尋，僅提供顯示(存名字，ID 建立之後就不提供修改與刪除)
	MediaURL []Media            `bson:"media_url" json:"media_url"` // 網址
	Like     int64              `bson:"like" json:"like"`           // 讚數量
	DisLike  int64              `bson:"dislike" json:"dislike"`     // 不讚數量
	UpdateAt int64              `bson:"updateAt,omitempty" json:"updateAt,omitempty"`
	CreateAt int64              `bson:"createAt,omitempty" json:"createAt,omitempty"` // -> 排序條件
}

type Media struct {
	Type  string // media type jpeg, m3u8 之類的
	Links string // 連結的網址
}

func (p *Post) CollectionName() string {
	return "post"
}

// 照邏輯，應該需要建立的索引有
// 單列索引：UID、Status、IsAd、CreateAt
// 複合索引：(UID + Status + IsAd)、(UID + CreateAt)
